@@ -1,12 +1,11 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020-2021 Devin Lin <devin@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCK_UTILMODEL_H
-#define KCLOCK_UTILMODEL_H
+#pragma once
 
 #include <QObject>
 #include <QString>
@@ -18,29 +17,26 @@ class UtilModel : public QObject
     Q_PROPERTY(QString tzName READ getCurrentTimeZoneName NOTIFY propertyChanged)
 
 public:
-    static UtilModel *instance()
-    {
-        static UtilModel *singleton = new UtilModel;
-        return singleton;
-    }
+    static UtilModel *instance();
+
+    Q_INVOKABLE QString getDefaultAlarmFileLocation();
 
     QString getCurrentTimeZoneName();
 
     long long calculateNextRingTime(int hours, int minutes, int daysOfWeek, int snooze = 0);
     QString timeToRingFormatted(const long long &timestamp);
 
-    bool isLocale24HourTime();
-
-    void setSelectedTimezone(QByteArray id, bool selected);
+    QString timeFormat();
+    bool use24HourTime();
 
 private:
     UtilModel(){}; // explicitly declare it private
+
+    bool isLocale24HourTime();
+
     bool m_applicationLoaded = false;
 
 Q_SIGNALS:
-    void selectedTimezoneChanged(QByteArray id, bool selected);
     void propertyChanged();
     void applicationLoadedChanged();
 };
-
-#endif // KCLOCK_UTILMODEL_H
