@@ -1,12 +1,11 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020-2021 Devin Lin <devin@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCKD_ALARMMODEL_H
-#define KCLOCKD_ALARMMODEL_H
+#pragma once
 
 #include "alarm.h"
 
@@ -14,23 +13,21 @@
 #include <QObject>
 
 class Alarm;
+
 class AlarmModel : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.AlarmModel")
+
 public:
-    static AlarmModel *instance()
-    {
-        static AlarmModel *singleton = new AlarmModel();
-        return singleton;
-    }
+    static AlarmModel *instance();
 
     void load();
     void save();
     void configureWakeups(); // needs to be called to start worker thread, or configure powerdevil (called in main)
 
     Q_SCRIPTABLE void removeAlarm(QString uuid);
-    Q_SCRIPTABLE void addAlarm(int hours, int minutes, int daysOfWeek, QString name, QString ringtonePath); // in 24 hours units
+    Q_SCRIPTABLE void addAlarm(QString name, int hours, int minutes, int daysOfWeek, QString audioPath, int ringDuration, int snoozeDuration);
 
 Q_SIGNALS:
     Q_SCRIPTABLE void alarmAdded(QString uuid);
@@ -41,22 +38,28 @@ public Q_SLOTS:
     Q_SCRIPTABLE quint64 getNextAlarm();
     void scheduleAlarm();
     void wakeupCallback(int cookie);
+
 private Q_SLOTS:
     void updateNotifierItem(quint64 time); // update notify icon in systemtray
 
 private:
-    void removeAlarm(int index);
-
     explicit AlarmModel(QObject *parent = nullptr);
 
+    void removeAlarm(int index);
     void initNotifierItem();
 
+    // next scheduled system wakeup for ringing alarms, in unix time
     quint64 m_nextAlarmTime = 0;
-    int m_cookie = -1; // token for wakeup call auth
-    QList<Alarm *> alarmsToRing; // the alarms that will ring on next wakeup
 
+    // token for system wakeup call authentication
+    int m_cookie = -1;
+
+    // list of alarms that will ring on the next scheduled system wakeup
+    QList<Alarm *> alarmsToRing;
+
+    // list of alarms in the model
     QList<Alarm *> m_alarmsList;
+
+    // system tray notifier item
     KStatusNotifierItem *m_item{nullptr};
 };
-
-#endif // KCLOCKD_ALARMMODEL_H
