@@ -10,6 +10,9 @@
 #include "kclockdsettings.h"
 #include "kclocksettingsadaptor.h"
 #include "timermodel.h"
+#include "utilities.h"
+#include "version.h"
+#include "xdgportal.h"
 
 #include <KAboutData>
 #include <KConfig>
@@ -36,17 +39,33 @@ int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("kclockd");
     KAboutData aboutData(QStringLiteral("kclockd"),
                          QStringLiteral("KClock daemon"),
-                         QStringLiteral("1.0"),
+                         QStringLiteral(KCLOCK_VERSION_STRING),
                          QStringLiteral("KClock daemon"),
                          KAboutLicense::GPL,
-                         i18n("© 2020-2021 KDE Community"));
+                         i18n("© 2020-2022 KDE Community"));
     aboutData.addAuthor(i18n("Devin Lin"), QLatin1String(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Han Young"), QLatin1String(), QStringLiteral("hanyoung@protonmail.com"));
     KAboutData::setApplicationData(aboutData);
 
+    // ~~~~ Parse command line arguments ~~~~
+    {
+        QScopedPointer<QCommandLineParser> parser(createParser());
+        parser->process(app);
+
+        if (parser->isSet(QStringLiteral("no-powerdevil"))) {
+            Utilities::disablePowerDevil(true);
+        }
+    }
+
     // only allow one instance
     KDBusService service(KDBusService::Unique);
 
+    qDebug() << "Starting kclockd" << KCLOCK_VERSION_STRING;
+
+    // call org.freedesktop.portal.Background for autostart in flatpak
+    XDGPortal *portalInterface = new XDGPortal();
+    portalInterface->requestBackground();
+
     // initialize models
     new KClockSettingsAdaptor(KClockSettings::self());
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"), KClockSettings::self());
